==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorTermBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TopologySelectorTermBuilder extends io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl<io.fabric8.kubernetes.api.model.TopologySelectorTermBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.TopologySelectorTerm,io.fabric8.kubernetes.api.model.TopologySelectorTermBuilder>{
  public TopologySelectorTermBuilder() {
    this(false);
  }
  public TopologySelectorTermBuilder(java.lang.Boolean validationEnabled) {
    this(new TopologySelectorTerm(), validationEnabled);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent) {
    this(fluent, false);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TopologySelectorTerm(), validationEnabled);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent,io.fabric8.kubernetes.api.model.TopologySelectorTerm instance) {
    this(fluent, instance, false);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent,io.fabric8.kubernetes.api.model.TopologySelectorTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMatchLabelExpressions(instance.getMatchLabelExpressions()); 
    this.validationEnabled = validationEnabled; 
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTerm instance) {
    this(instance,false);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMatchLabelExpressions(instance.getMatchLabelExpressions()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.TopologySelectorTerm build() {
    TopologySelectorTerm buildable = new TopologySelectorTerm(fluent.getMatchLabelExpressions());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TopologySelectorTermBuilder that = (TopologySelectorTermBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/TopologySelectorTermBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TopologySelectorTermBuilder extends io.fabric8.kubernetes.api.model.TopologySelectorTermFluentImpl<io.fabric8.kubernetes.api.model.TopologySelectorTermBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.TopologySelectorTerm,io.fabric8.kubernetes.api.model.TopologySelectorTermBuilder>{
  public TopologySelectorTermBuilder() {
    this(false);
  }
  public TopologySelectorTermBuilder(java.lang.Boolean validationEnabled) {
    this(new TopologySelectorTerm(), validationEnabled);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent) {
    this(fluent, false);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TopologySelectorTerm(), validationEnabled);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent,io.fabric8.kubernetes.api.model.TopologySelectorTerm instance) {
    this(fluent, instance, false);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent,io.fabric8.kubernetes.api.model.TopologySelectorTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMatchLabelExpressions(instance.getMatchLabelExpressions()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTerm instance) {
    this(instance,false);
  }
  public TopologySelectorTermBuilder(io.fabric8.kubernetes.api.model.TopologySelectorTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMatchLabelExpressions(instance.getMatchLabelExpressions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.TopologySelectorTermFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.TopologySelectorTerm build() {
    TopologySelectorTerm buildable = new TopologySelectorTerm(fluent.getMatchLabelExpressions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TopologySelectorTermBuilder that = (TopologySelectorTermBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
